//+------------------------------------------------------------------+
//|                                                    Pinbar EA.mq4 |
//|                        Copyright 2020, MetaQuotes Software Corp. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2020, MetaQuotes Software Corp."
#property link      "https://www.mql5.com"
#property version   "1.00"
#property strict

double Open1;
double Close1;
double High1;
double Low1;
double MA;
double Risk;

extern double Lot_Size = 0.01;
extern double Risk_Reward_Ratio = 1.5;
extern double Buffer_Point = 50;

//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {

   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
   Open1 = NormalizeDouble(iOpen(Symbol(), Period(), 1), Digits);
   Close1 = NormalizeDouble(iClose(Symbol(), Period(), 1), Digits);
   High1 = NormalizeDouble(iHigh(Symbol(), Period(), 1), Digits);
   Low1 = NormalizeDouble(iLow(Symbol(), Period(), 1), Digits);
   MA = iMA(Symbol(), PERIOD_CURRENT, 50, 0, MODE_EMA, PRICE_CLOSE, 1);
   Risk = (High1-Low1) + Buffer_Point*Point;
     
   if ((Low1 < MA) && (Close1 > MA) && CheckBullishPinbar()) Long();
   if ((High1 > MA) && (Close1 < MA) && CheckBearishPinbar()) Short();
   
   if ((OrdersTotal() >=1) && CheckBuyStopOrder()) DeletePendingOrder();
   if ((OrdersTotal() >=1) && CheckSellStopOrder()) DeletePendingOrder();
  }
//+------------------------------------------------------------------+
bool CheckBullishPinbar()
   {      
    bool Pinbar;
    if (
        Close1 > Low1 + 0.75 * (High1-Low1) && //Candlestick Close > Candlestick Low + 75% * Candlestick Range
        Open1 > Low1 + 0.75 * (High1 - Low1) && //Candlestick Open > Candlestick Low + 75% * Candlestick Range
        MathAbs(Open1 - Close1) < 0.25 * (High1 - Low1) //Candlestick Body < 25% * Candlestick Range        
       ) Pinbar=true;
     return(Pinbar);
    }
   
bool CheckBearishPinbar()
   {   
   bool Pinbar;
    if (
        Close1 < High1 - 0.75 * (High1-Low1) && //Candlestick Close < Candlestick Low - 75% * Candlestick Range
        Open1 < High1 - 0.75 * (High1 - Low1) && //Candlestick Open < Candlestick Low - 75% * Candlestick Range
        MathAbs(Open1 - Close1) < 0.25 * (High1 - Low1) //Candlestick Body < 25% * Candlestick Range        
       )
       Pinbar=true;
  return(Pinbar);    
   }
   
void Long() 
   {
    if (OrdersTotal() == 0) 
    {       
     int LongTicket = OrderSend (Symbol(), OP_BUYSTOP, Lot_Size, NormalizeDouble((High1+Buffer_Point*Point),Digits), 3,
     Low1, 
     NormalizeDouble(((High1+Buffer_Point*Point)+(Risk_Reward_Ratio*Risk)),Digits),"BUY", 
     123456,
     0, 
     clrNONE);
     if(GetLastError()!=0) Print(" BUY Error ",GetLastError());
    }
   }
   
void Short() 
   {
    if (OrdersTotal() == 0) 
    {    
     int ShortTicket = OrderSend (Symbol(), OP_SELLSTOP, Lot_Size, Low1-50*Point, 3,
     High1, 
     NormalizeDouble(((Low1-Buffer_Point*Point)-(Risk_Reward_Ratio*Risk)),Digits), "SELL", 
     123456, 
     0, 
     clrNONE);
     if(GetLastError()!=0) Print(" SELL Error ",GetLastError());    
    }
   }
   
bool CheckBuyStopOrder()
   {   
   bool Rule;   
    for (int i = OrdersTotal() - 1; i >= 0; i--)
    if (OrderSelect (i, SELECT_BY_POS, MODE_TRADES))
    if (OrderSymbol() == Symbol())
    if (OrderType() == OP_BUYLIMIT)
    if (OrderStopLoss() > Close1)       
       Rule=true;
  return(Rule);
    
   }
   
bool CheckSellStopOrder()
   {   
   bool Rule;
    for (int i = OrdersTotal() - 1; i >= 0; i--)
    if (OrderSelect (i, SELECT_BY_POS, MODE_TRADES))
    if (OrderSymbol() == Symbol())
    if (OrderType() == OP_SELLLIMIT)
    if (OrderStopLoss() < Close1) 
       Rule=true;
  return(Rule);    
   }
   
void DeletePendingOrder()
  {   
   int result=OrderDelete(OrderTicket());   
  }